@@ -16,18 +16,17 @@ Author:
 Notes:
 
 --*/
-#ifndef Z3_FIXEDPOINT_H_
-#define Z3_FIXEDPOINT_H_
+#pragma once
 
 #ifdef __cplusplus
 extern "C" {
 #endif // __cplusplus
 
     /** \defgroup capi C API */
-    /*@{*/
+    /**@{*/
 
     /** @name Fixedpoint facilities */
-    /*@{*/
+    /**@{*/
     /**
        \brief Create a new fixedpoint context.
 
@@ -110,7 +109,7 @@ extern "C" {
         - \c Z3_L_TRUE if the query is satisfiable. Obtain the answer by calling #Z3_fixedpoint_get_answer.
         - \c Z3_L_UNDEF if the query was interrupted, timed out or otherwise failed.
 
-        def_API('Z3_fixedpoint_query', INT, (_in(CONTEXT), _in(FIXEDPOINT), _in(AST)))
+        def_API('Z3_fixedpoint_query', LBOOL, (_in(CONTEXT), _in(FIXEDPOINT), _in(AST)))
     */
     Z3_lbool Z3_API Z3_fixedpoint_query(Z3_context c, Z3_fixedpoint d, Z3_ast query);
 
@@ -124,7 +123,7 @@ extern "C" {
         - \c Z3_L_TRUE if the query is satisfiable. Obtain the answer by calling #Z3_fixedpoint_get_answer.
         - \c Z3_L_UNDEF if the query was interrupted, timed out or otherwise failed.
 
-        def_API('Z3_fixedpoint_query_relations', INT, (_in(CONTEXT), _in(FIXEDPOINT), _in(UINT), _in_array(2, FUNC_DECL)))
+        def_API('Z3_fixedpoint_query_relations', LBOOL, (_in(CONTEXT), _in(FIXEDPOINT), _in(UINT), _in_array(2, FUNC_DECL)))
     */
     Z3_lbool Z3_API Z3_fixedpoint_query_relations(
         Z3_context c, Z3_fixedpoint d,
@@ -334,29 +333,6 @@ extern "C" {
                                                  Z3_fixedpoint f,
                                                  Z3_string s);
 
-    /**
-       \brief Create a backtracking point.
-
-       The fixedpoint solver contains a set of rules, added facts and assertions.
-       The set of rules, facts and assertions are restored upon calling #Z3_fixedpoint_pop.
-
-       \sa Z3_fixedpoint_pop
-
-       def_API('Z3_fixedpoint_push', VOID, (_in(CONTEXT), _in(FIXEDPOINT)))
-    */
-    void Z3_API Z3_fixedpoint_push(Z3_context c, Z3_fixedpoint d);
-
-    /**
-       \brief Backtrack one backtracking point.
-
-       \sa Z3_fixedpoint_push
-
-       \pre The number of calls to pop cannot exceed calls to push.
-
-       def_API('Z3_fixedpoint_pop', VOID, (_in(CONTEXT), _in(FIXEDPOINT)))
-    */
-    void Z3_API Z3_fixedpoint_pop(Z3_context c, Z3_fixedpoint d);
-
     /** \brief The following utilities allows adding user-defined domains. */
 
     typedef void Z3_fixedpoint_reduce_assign_callback_fptr(
@@ -397,11 +373,10 @@ extern "C" {
 
     void Z3_API Z3_fixedpoint_add_constraint (Z3_context c, Z3_fixedpoint d, Z3_ast e, unsigned lvl);
 
-    /*@}*/
-    /*@}*/
+    /**@}*/
+    /**@}*/
 
 #ifdef __cplusplus
 }
 #endif // __cplusplus
 
-#endif
